pub enum TimestampUnit {
Ms,
Us,
Ns,
}Expand description
Converting the TimestampUnit enum to a string representation for Polars breaks
on “μs” when passing from rust to python. We handle that here by converting it to “us”.
Variants